@@ -81,9 +81,12 @@
                                  "rxode2::rxSolve",
                                  "rxode2::rxClean",
                                  "rxode2::rxCat",
+                                 "rxode2::rxSetPipingAuto",
                                  "rxode2::eventTable",
                                  "rxode2::add.dosing",
                                  "rxode2::add.sampling",
+                                 "rxode2::rxFun",
+                                 "nlmixr2est::nlmixr2AllEst",
                                  "nlmixr2est::pdDiag",
                                  "nlmixr2est::pdSymm",
                                  "nlmixr2est::pdLogChol",
@@ -106,6 +109,9 @@
                                  "nlmixr2est::varComb",
                                  "nlmixr2est::groupedData",
                                  "nlmixr2est::getData",
+                                 "rxode2::`model<-`",
+                                 "rxode2::`ini<-`",
+                                 "rxode2::etExpand",
                                  "rxode2::et",
                                  "rxode2::rxParams",
                                  "rxode2::rxParam",
@@ -126,7 +132,8 @@
                                  "nlmixr2est::.nlmixrNlmeFun",
                                  "nlmixr2est::nlmixr2NlmeControl",
                                  "nlmixr2est::nlmixr",
-                                 "lotri::lotri"),
+                                 "lotri::lotri"
+                                 ),
                           hard=c("nlmixr2plot::traceplot",
                                  "nlmixr2est::vpcSim",
                                  "nlmixr2plot::vpcPlot",
